automation-suite
2023.10
false
Guía de referencia de uipathctl
- Información general
- Preinstalación
- Instalación
- Administración de clústeres
- clúster uipathctl
- mantenimiento del clúster de uipathctl
- uipathctl cluster maintenance disable
- uipathctl cluster maintenance enable
- uipathctl cluster maintenance is-enabled
- uipathctl cluster migration
- uipathctl cluster migration export
- uipathctl cluster migration import
- uipathctl cluster migration run
- uipathctl config add-host-admin
- uipathctl config argocd
- uipathctl config argocd registry
- uipathctl config argocd registry get
- uipathctl config argocd registry update
- versión de uipathctl
- Copias de seguridad y restauración
- instantánea de uipathctl
- copia de seguridad de instantánea de uipathctl
- uipathctl snapshot backup create
- uipathctl snapshot backup disable
- uipathctl snapshot backup enable
- uipathctl snapshot delete
- uipathctl snapshot list
- uipathctl snapshot restore
- uipathctl snapshot restore create
- uipathctl snapshot restore delete
- uipathctl snapshot restore history
- uipathctl snapshot restore logs
- Gestión de certificados
- uipathctl config additional-ca-certificates
- uipathctl config additional-ca-certificates get
- uipathctl config additional-ca-certificates update
- uipathctl config argocd ca-certificates
- uipathctl config argocd ca-certificates get
- uipathctl config argocd ca-certificates update
- uipathctl config saml-certificates
- uipathctl config saml-certificates get
- uipathctl config saml-certificates rotate
- uipathctl config saml-certificates update
- uipathctl config tls-certificates
- uipathctl config tls-certificates get
- uipathctl config tls-certificates update
- uipathctl config token-signing-certificates
- uipathctl config token-signing-certificates get
- uipathctl config token-signing-certificates rotate
- uipathctl config token-signing-certificates update
- Actualizar
- Autenticación
- Supervisión y alertas
- Configuración específica del producto
- orchestrator de configuración de uipathctl
- get-config de uipathctl config del orquestador
- uipathctl config orchestrator update-config
- Solución de problemas
Importante :
La localización de contenidos recién publicados puede tardar entre una y dos semanas en estar disponible.
uipathctl config orchestrator update-config
Referencia para el comando uipathctl config Orchestrator update-config y sus marcadores para actualizar la configuración personalizada de Orchestrator en Automation Suite.
Descripción
Actualice la configuración personalizada del componente de Orchestrator.
El comando tiene como valor predeterminado el contexto actual en el archivo kubeconfig . Si se establece el --kubeconfig , usará el archivo kubeconfig especificado por el marcador.
uipathctl config orchestrator update-config [flags]
uipathctl config orchestrator update-config [flags]
Ejemplos
# Update orchestrator nlog configuration from the cluster
uipathctl config orchestrator update-config --nlog-config nlog.custom.json
# Update orchestrator app settings configuration from the cluster
uipathctl config orchestrator update-config --app-settings appsettings.custom.json
# Update orchestrator nlog configuration from the cluster identified by the current context in the kubeconfig file
uipathctl config orchestrator update-config --nlog-config nlog.custom.json --kubeconfig cluster.kubeconfig
# Update orchestrator nlog configuration from the cluster
uipathctl config orchestrator update-config --nlog-config nlog.custom.json
# Update orchestrator app settings configuration from the cluster
uipathctl config orchestrator update-config --app-settings appsettings.custom.json
# Update orchestrator nlog configuration from the cluster identified by the current context in the kubeconfig file
uipathctl config orchestrator update-config --nlog-config nlog.custom.json --kubeconfig cluster.kubeconfig
Opciones
--app-settings string path to application settings config file in json format
-h, --help help for update-config
--nlog-config string path to nlog config file in json format
--app-settings string path to application settings config file in json format
-h, --help help for update-config
--nlog-config string path to nlog config file in json format
Opciones heredadas de los comandos principales
--context string name of the kubeconfig context to use
--kubeconfig string kubectl configuration file (default: ~/.kube/config)
--log-format string log format. one of [text,json] (default "text")
--log-level string set log level. one of [trace,debug,info,error] (default "error")
--timeout duration timeout of the command (default 1h0m0s)
--context string name of the kubeconfig context to use
--kubeconfig string kubectl configuration file (default: ~/.kube/config)
--log-format string log format. one of [text,json] (default "text")
--log-level string set log level. one of [trace,debug,info,error] (default "error")
--timeout duration timeout of the command (default 1h0m0s)